@@ -41,8 +41,6 @@ use IPC::PrettyPipe::Types -all;
 use IPC::PrettyPipe::Queue;
 use IPC::PrettyPipe::Arg::Format;
 
-use String::ShellQuote 'shell_quote';
-
 with 'IPC::PrettyPipe::Queue::Element';
 
 IPC::PrettyPipe::Arg::Format
@@ -118,8 +116,6 @@ sub BUILD {
     return;
 }
 
-sub quoted_cmd {  shell_quote( $_[0]->cmd )  }
-
 sub add {
 
     my $self = shift;
@@ -466,11 +462,6 @@ An B<L<IPC::PrettyPipe::Arg>> object;
 
 =item *
 
-A hashref with pairs of names and values. The arguments will be
-supplied to the command in a random order.
-
-=item *
-
 An array reference containing more complex argument specifications.
 Its elements are processed with the B<L</ffadd>> method.
 
@@ -557,10 +548,10 @@ This will override the format attributes for this argument only.
 
 =item B<args>
 
-  $args = $cmd->args;
+  $args = $cmd->args
 
-Return a B<L<IPC::PrettyPipe::Queue>> object containing the
-B<L<IPC::PrettyPipe::Arg>> objects associated with the command.
+Returns an B<L<IPC::PrettyPipe::Queue>> object containing the
+arguments associated with the command.
 
 =item B<argpfx>,
 
@@ -579,13 +570,6 @@ affects new, not existing, arguments;
 
 Return the name of the command.
 
-=item B<quoted_cmd>
-
-  $name = $cmd->quoted_cmd
-
-Return the name of the command, appropriately quoted for passing as a
-single word to a Bourne compatible shell.
-
 =item B<ffadd>
 
   $cmd->ffadd( @arguments );
@@ -648,8 +632,8 @@ See B<L<IPC::PrettyPipe::Stream>> for more information.
 
   $streams = $cmd->streams
 
-Return a B<L<IPC::PrettyPipe::Queue>> object containing the
-B<L<IPC::PrettyPipe::Stream>> objects associated with the command.
+Return an B<L<IPC::PrettyPipe::Queue>> object containing the streams
+associated with the command.
 
 =item B<valmatch>
 
